package org.jeecg.modules.system.app.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Param;
import org.jeecg.modules.system.app.entity.ShopMoney;

import java.util.List;
import java.util.Map;

public interface IStatisticsService {
    /**
     * <p>管理端首页获取商品销量排行</p>
     * @author SheepHy
     * @param 参数描述，参数为类则包含{@link Object}
     * @return 返回值描述，如无返回值则为void 返回值为类则包含{@link object}
     *
     */
    List<Map<String, Object>> findByShopSum(int type);

    /**
     * <p>管理端首页获取部门售额排行</p>
     * @author SheepHy
     * @param 参数描述，参数为类则包含{@link Object}
     * @return 返回值描述，如无返回值则为void 返回值为类则包含{@link object}
     *
     */
    List<Map<String, Object>> findByDeptSum(int type);

    /**
     * <p>首页统计</p>
     * @author SheepHy
     * @param 参数描述，参数为类则包含{@link Object}
     * @return 返回值描述，如无返回值则为void 返回值为类则包含{@link object}
     *
     */
    Map<String, Object> findIndexStatistics();

    /**
     * <p>本月销售额趋势图</p>
     * @author SheepHy
     * @param 参数描述，参数为类则包含{@link Object}
     * @return 返回值描述，如无返回值则为void 返回值为类则包含{@link object}
     *
     */
    List<Map<String, Object>> findMonthSaleTrend();

    /**
     * <p>分页查询店铺资金总览</p>
     * @author SheepHy
     * @param 参数描述，参数为类则包含{@link Object}
     * @return 返回值描述，如无返回值则为void 返回值为类则包含{@link object}
     *
     */
    List<Map<String, Object>> findShopAccountOverview(Page<Map<String, Object>> page,String name);

    /**
     * <p>查询店铺资金总览-门店统计</p>
     * @author SheepHy
     * @param 参数描述，参数为类则包含{@link Object}
     * @return 返回值描述，如无返回值则为void 返回值为类则包含{@link object}
     *
     */
    List<Map<String, Object>> findShopAccountOverviewDept();

    /**
     * <p>分页查询店铺资金总览-门店</p>
     * @author SheepHy
     * @param 参数描述，参数为类则包含{@link Object}
     * @return 返回值描述，如无返回值则为void 返回值为类则包含{@link object}
     *
     */
    Page<ShopMoney> selectFundChanges(Page<ShopMoney> page,
                                      int incomeType,
                                      int moneyType,
                                      int changeInfo);

}
